Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: chrome/browser/password_manager/native_backend_libsecret_unittest.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/password_manager/native_backend_libsecret_unittest.cc
diff --git a/chrome/browser/password_manager/native_backend_libsecret_unittest.cc b/chrome/browser/password_manager/native_backend_libsecret_unittest.cc
index 031395f95ebda3128fb158142b5458fbe4597b98..19f6ca86fd19bdbcebdef22bc04bfbda2859524d 100644
--- a/chrome/browser/password_manager/native_backend_libsecret_unittest.cc
+++ b/chrome/browser/password_manager/native_backend_libsecret_unittest.cc
@@ -396,10 +396,10 @@ class NativeBackendLibsecretTest : public testing::Test {
base::Int64ToString(form.date_synced.ToInternalValue()));
CheckStringAttribute(item, "display_name", UTF16ToUTF8(form.display_name));
CheckStringAttribute(item, "avatar_url", form.icon_url.spec());
// We serialize unique origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310
CheckStringAttribute(item, "federation_url",
- form.federation_origin.unique()
+ form.federation_origin.opaque()
? ""
: form.federation_origin.Serialize());
CheckUint32Attribute(item, "should_skip_zero_click", form.skip_zero_click);
@@ -396,10 +396,10 @@ class NativeBackendLibsecretTest : public testing::Test {
CheckStringAttribute(item, "display_name", UTF16ToUTF8(form.display_name));
CheckStringAttribute(item, "avatar_url", form.icon_url.spec());
- // We serialize unique origins as "", in order to make other systems that
+ // We serialize opaque origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310
CheckStringAttribute(item, "federation_url",

Powered by Google App Engine
This is Rietveld 408576698